==> ph-xsds-xmldsig11-2.0.0-sources.jar: com/helger/xsds/xmldsig11/ObjectFactory.java <==

package com.helger.xsds.xmldsig11;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.helger.xsds.xmldsig11 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _ECKeyValue_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "ECKeyValue");
    public final static QName _Prime_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "Prime");
    public final static QName _GnB_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "GnB");
    public final static QName _TnB_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "TnB");
    public final static QName _PnB_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "PnB");
    public final static QName _DEREncodedKeyValue_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "DEREncodedKeyValue");
    public final static QName _KeyInfoReference_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "KeyInfoReference");
    public final static QName _X509Digest_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "X509Digest");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.helger.xsds.xmldsig11
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ECKeyValueType }
     * 
     * @return
     *     The created ECKeyValueType object and never <code>null</code>.
     */
    @Nonnull
    public ECKeyValueType createECKeyValueType() {
        return new ECKeyValueType();
    }

    /**
     * Create an instance of {@link PrimeFieldParamsType }
     * 
     * @return
     *     The created PrimeFieldParamsType object and never <code>null</code>.
     */
    @Nonnull
    public PrimeFieldParamsType createPrimeFieldParamsType() {
        return new PrimeFieldParamsType();
    }

    /**
     * Create an instance of {@link CharTwoFieldParamsType }
     * 
     * @return
     *     The created CharTwoFieldParamsType object and never <code>null</code>.
     */
    @Nonnull
    public CharTwoFieldParamsType createCharTwoFieldParamsType() {
        return new CharTwoFieldParamsType();
    }

    /**
     * Create an instance of {@link TnBFieldParamsType }
     * 
     * @return
     *     The created TnBFieldParamsType object and never <code>null</code>.
     */
    @Nonnull
    public TnBFieldParamsType createTnBFieldParamsType() {
        return new TnBFieldParamsType();
    }

    /**
     * Create an instance of {@link PnBFieldParamsType }
     * 
     * @return
     *     The created PnBFieldParamsType object and never <code>null</code>.
     */
    @Nonnull
    public PnBFieldParamsType createPnBFieldParamsType() {
        return new PnBFieldParamsType();
    }

    /**
     * Create an instance of {@link DEREncodedKeyValueType }
     * 
     * @return
     *     The created DEREncodedKeyValueType object and never <code>null</code>.
     */
    @Nonnull
    public DEREncodedKeyValueType createDEREncodedKeyValueType() {
        return new DEREncodedKeyValueType();
    }

    /**
     * Create an instance of {@link KeyInfoReferenceType }
     * 
     * @return
     *     The created KeyInfoReferenceType object and never <code>null</code>.
     */
    @Nonnull
    public KeyInfoReferenceType createKeyInfoReferenceType() {
        return new KeyInfoReferenceType();
    }

    /**
     * Create an instance of {@link X509DigestType }
     * 
     * @return
     *     The created X509DigestType object and never <code>null</code>.
     */
    @Nonnull
    public X509DigestType createX509DigestType() {
        return new X509DigestType();
    }

    /**
     * Create an instance of {@link NamedCurveType }
     * 
     * @return
     *     The created NamedCurveType object and never <code>null</code>.
     */
    @Nonnull
    public NamedCurveType createNamedCurveType() {
        return new NamedCurveType();
    }

    /**
     * Create an instance of {@link ECParametersType }
     * 
     * @return
     *     The created ECParametersType object and never <code>null</code>.
     */
    @Nonnull
    public ECParametersType createECParametersType() {
        return new ECParametersType();
    }

    /**
     * Create an instance of {@link FieldIDType }
     * 
     * @return
     *     The created FieldIDType object and never <code>null</code>.
     */
    @Nonnull
    public FieldIDType createFieldIDType() {
        return new FieldIDType();
    }

    /**
     * Create an instance of {@link CurveType }
     * 
     * @return
     *     The created CurveType object and never <code>null</code>.
     */
    @Nonnull
    public CurveType createCurveType() {
        return new CurveType();
    }

    /**
     * Create an instance of {@link ECValidationDataType }
     * 
     * @return
     *     The created ECValidationDataType object and never <code>null</code>.
     */
    @Nonnull
    public ECValidationDataType createECValidationDataType() {
        return new ECValidationDataType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ECKeyValueType }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "ECKeyValue")
    @Nonnull
    public JAXBElement<ECKeyValueType> createECKeyValue(
        @Nullable
        final ECKeyValueType value) {
        return new JAXBElement<ECKeyValueType>(_ECKeyValue_QNAME, ECKeyValueType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PrimeFieldParamsType }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "Prime")
    @Nonnull
    public JAXBElement<PrimeFieldParamsType> createPrime(
        @Nullable
        final PrimeFieldParamsType value) {
        return new JAXBElement<PrimeFieldParamsType>(_Prime_QNAME, PrimeFieldParamsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CharTwoFieldParamsType }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "GnB")
    @Nonnull
    public JAXBElement<CharTwoFieldParamsType> createGnB(
        @Nullable
        final CharTwoFieldParamsType value) {
        return new JAXBElement<CharTwoFieldParamsType>(_GnB_QNAME, CharTwoFieldParamsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TnBFieldParamsType }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "TnB")
    @Nonnull
    public JAXBElement<TnBFieldParamsType> createTnB(
        @Nullable
        final TnBFieldParamsType value) {
        return new JAXBElement<TnBFieldParamsType>(_TnB_QNAME, TnBFieldParamsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PnBFieldParamsType }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "PnB")
    @Nonnull
    public JAXBElement<PnBFieldParamsType> createPnB(
        @Nullable
        final PnBFieldParamsType value) {
        return new JAXBElement<PnBFieldParamsType>(_PnB_QNAME, PnBFieldParamsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DEREncodedKeyValueType }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "DEREncodedKeyValue")
    @Nonnull
    public JAXBElement<DEREncodedKeyValueType> createDEREncodedKeyValue(
        @Nullable
        final DEREncodedKeyValueType value) {
        return new JAXBElement<DEREncodedKeyValueType>(_DEREncodedKeyValue_QNAME, DEREncodedKeyValueType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link KeyInfoReferenceType }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "KeyInfoReference")
    @Nonnull
    public JAXBElement<KeyInfoReferenceType> createKeyInfoReference(
        @Nullable
        final KeyInfoReferenceType value) {
        return new JAXBElement<KeyInfoReferenceType>(_KeyInfoReference_QNAME, KeyInfoReferenceType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link X509DigestType }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "X509Digest")
    @Nonnull
    public JAXBElement<X509DigestType> createX509Digest(
        @Nullable
        final X509DigestType value) {
        return new JAXBElement<X509DigestType>(_X509Digest_QNAME, X509DigestType.class, null, value);
    }

}

==> ph-xsds-xmldsig11-2.2.6-sources.jar: com/helger/xsds/xmldsig11/ObjectFactory.java <==

package com.helger.xsds.xmldsig11;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.helger.xsds.xmldsig11 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _ECKeyValue_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "ECKeyValue");
    public final static QName _Prime_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "Prime");
    public final static QName _GnB_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "GnB");
    public final static QName _TnB_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "TnB");
    public final static QName _PnB_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "PnB");
    public final static QName _DEREncodedKeyValue_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "DEREncodedKeyValue");
    public final static QName _KeyInfoReference_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "KeyInfoReference");
    public final static QName _X509Digest_QNAME = new QName("http://www.w3.org/2009/xmldsig11#", "X509Digest");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.helger.xsds.xmldsig11
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ECKeyValueType }
     * 
     * @return
     *     The created ECKeyValueType object and never <code>null</code>.
     */
    @Nonnull
    public ECKeyValueType createECKeyValueType() {
        return new ECKeyValueType();
    }

    /**
     * Create an instance of {@link PrimeFieldParamsType }
     * 
     * @return
     *     The created PrimeFieldParamsType object and never <code>null</code>.
     */
    @Nonnull
    public PrimeFieldParamsType createPrimeFieldParamsType() {
        return new PrimeFieldParamsType();
    }

    /**
     * Create an instance of {@link CharTwoFieldParamsType }
     * 
     * @return
     *     The created CharTwoFieldParamsType object and never <code>null</code>.
     */
    @Nonnull
    public CharTwoFieldParamsType createCharTwoFieldParamsType() {
        return new CharTwoFieldParamsType();
    }

    /**
     * Create an instance of {@link TnBFieldParamsType }
     * 
     * @return
     *     The created TnBFieldParamsType object and never <code>null</code>.
     */
    @Nonnull
    public TnBFieldParamsType createTnBFieldParamsType() {
        return new TnBFieldParamsType();
    }

    /**
     * Create an instance of {@link PnBFieldParamsType }
     * 
     * @return
     *     The created PnBFieldParamsType object and never <code>null</code>.
     */
    @Nonnull
    public PnBFieldParamsType createPnBFieldParamsType() {
        return new PnBFieldParamsType();
    }

    /**
     * Create an instance of {@link DEREncodedKeyValueType }
     * 
     * @return
     *     The created DEREncodedKeyValueType object and never <code>null</code>.
     */
    @Nonnull
    public DEREncodedKeyValueType createDEREncodedKeyValueType() {
        return new DEREncodedKeyValueType();
    }

    /**
     * Create an instance of {@link KeyInfoReferenceType }
     * 
     * @return
     *     The created KeyInfoReferenceType object and never <code>null</code>.
     */
    @Nonnull
    public KeyInfoReferenceType createKeyInfoReferenceType() {
        return new KeyInfoReferenceType();
    }

    /**
     * Create an instance of {@link X509DigestType }
     * 
     * @return
     *     The created X509DigestType object and never <code>null</code>.
     */
    @Nonnull
    public X509DigestType createX509DigestType() {
        return new X509DigestType();
    }

    /**
     * Create an instance of {@link NamedCurveType }
     * 
     * @return
     *     The created NamedCurveType object and never <code>null</code>.
     */
    @Nonnull
    public NamedCurveType createNamedCurveType() {
        return new NamedCurveType();
    }

    /**
     * Create an instance of {@link ECParametersType }
     * 
     * @return
     *     The created ECParametersType object and never <code>null</code>.
     */
    @Nonnull
    public ECParametersType createECParametersType() {
        return new ECParametersType();
    }

    /**
     * Create an instance of {@link FieldIDType }
     * 
     * @return
     *     The created FieldIDType object and never <code>null</code>.
     */
    @Nonnull
    public FieldIDType createFieldIDType() {
        return new FieldIDType();
    }

    /**
     * Create an instance of {@link CurveType }
     * 
     * @return
     *     The created CurveType object and never <code>null</code>.
     */
    @Nonnull
    public CurveType createCurveType() {
        return new CurveType();
    }

    /**
     * Create an instance of {@link ECValidationDataType }
     * 
     * @return
     *     The created ECValidationDataType object and never <code>null</code>.
     */
    @Nonnull
    public ECValidationDataType createECValidationDataType() {
        return new ECValidationDataType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ECKeyValueType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ECKeyValueType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "ECKeyValue")
    @Nonnull
    public JAXBElement<ECKeyValueType> createECKeyValue(
        @Nullable
        final ECKeyValueType value) {
        return new JAXBElement<ECKeyValueType>(_ECKeyValue_QNAME, ECKeyValueType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PrimeFieldParamsType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link PrimeFieldParamsType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "Prime")
    @Nonnull
    public JAXBElement<PrimeFieldParamsType> createPrime(
        @Nullable
        final PrimeFieldParamsType value) {
        return new JAXBElement<PrimeFieldParamsType>(_Prime_QNAME, PrimeFieldParamsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CharTwoFieldParamsType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link CharTwoFieldParamsType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "GnB")
    @Nonnull
    public JAXBElement<CharTwoFieldParamsType> createGnB(
        @Nullable
        final CharTwoFieldParamsType value) {
        return new JAXBElement<CharTwoFieldParamsType>(_GnB_QNAME, CharTwoFieldParamsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TnBFieldParamsType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TnBFieldParamsType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "TnB")
    @Nonnull
    public JAXBElement<TnBFieldParamsType> createTnB(
        @Nullable
        final TnBFieldParamsType value) {
        return new JAXBElement<TnBFieldParamsType>(_TnB_QNAME, TnBFieldParamsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PnBFieldParamsType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link PnBFieldParamsType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "PnB")
    @Nonnull
    public JAXBElement<PnBFieldParamsType> createPnB(
        @Nullable
        final PnBFieldParamsType value) {
        return new JAXBElement<PnBFieldParamsType>(_PnB_QNAME, PnBFieldParamsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DEREncodedKeyValueType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link DEREncodedKeyValueType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "DEREncodedKeyValue")
    @Nonnull
    public JAXBElement<DEREncodedKeyValueType> createDEREncodedKeyValue(
        @Nullable
        final DEREncodedKeyValueType value) {
        return new JAXBElement<DEREncodedKeyValueType>(_DEREncodedKeyValue_QNAME, DEREncodedKeyValueType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link KeyInfoReferenceType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link KeyInfoReferenceType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "KeyInfoReference")
    @Nonnull
    public JAXBElement<KeyInfoReferenceType> createKeyInfoReference(
        @Nullable
        final KeyInfoReferenceType value) {
        return new JAXBElement<KeyInfoReferenceType>(_KeyInfoReference_QNAME, KeyInfoReferenceType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link X509DigestType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link X509DigestType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://www.w3.org/2009/xmldsig11#", name = "X509Digest")
    @Nonnull
    public JAXBElement<X509DigestType> createX509Digest(
        @Nullable
        final X509DigestType value) {
        return new JAXBElement<X509DigestType>(_X509Digest_QNAME, X509DigestType.class, null, value);
    }

}
